@@ -15,7 +15,7 @@ def wrap_in_module(node):
     return new_node
 
 def assert_ast(state, element, fmt_kwargs):
-    patt = "__JINJA__:You are zooming in on the {{part}}, but it is not an AST, so it can't be re-run."
+    patt = "You are zooming in on the {{part}}, but it is not an AST, so it can't be re-run."
     _err_msg = "SCT fails on solution: "
     _err_msg += state.build_message(patt, fmt_kwargs)
     # element can also be { 'node': AST }
